@@ -1,6 +1,6 @@
 <?php
 /*
- * $Horde: horde/lib/Horde.php,v 1.118.2.56 2004/10/25 15:59:15 chuck Exp $
+ * $Horde: horde/lib/Horde.php,v 1.118.2.57 2005/11/13 11:48:32 jan Exp $
  *
  * Copyright 1999-2003 Chuck Hagenbuch <chuck@horde.org>
  * Copyright 1999-2003 Jon Parise <jon@horde.org>
@@ -120,7 +120,7 @@ function _fileCleanup($filename = false, $register = true)
  *
  * @author  Chuck Hagenbuch <chuck@horde.org>
  * @author  Jon Parise <jon@horde.org>
- * @version $Revision: 1.118.2.56 $
+ * @version $Revision: 1.118.2.57 $
  * @since   Horde 1.3
  * @package horde
  */
@@ -234,7 +234,7 @@ class Horde {
 
         $errortext = _("<b>A fatal error has occurred:</b>") . "<br /><br />\n";
         if (is_object($error) && method_exists($error, 'getMessage')) {
-            $errortext .= $error->getMessage() . "<br /><br />\n";
+            $errortext .= htmlspecialchars($error->getMessage()) . "<br /><br />\n";
         }
         $errortext .= sprintf(_("[line %s of %s]"), $line, $file);
 
