@@ -1,5 +1,13 @@
 <?php
-// $Horde: horde/lib/Menu.php,v 1.12.2.1 2002/04/05 01:24:21 jon Exp $
+/*
+ * $Horde: horde/lib/Menu.php,v 1.12.2.4 2003/01/03 12:48:37 jan Exp $
+ *
+ * Copyright 1999-2003 Chuck Hagenbuch <chuck@horde.org>
+ * Copyright 1999-2003 Jon Parise <jon@horde.org>
+ *
+ * See the enclosed file COPYING for license information (LGPL). If you
+ * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
+ */
 
 /**
  * The Menu:: class provides standardized methods for creating menus in
@@ -7,7 +15,7 @@
  *
  * @author  Chuck Hagenbuch <chuck@horde.org>
  * @author  Jon Parise <jon@horde.org>
- * @version $Revision: 1.12.2.1 $
+ * @version $Revision: 1.12.2.4 $
  * @since   Horde 1.3
  * @package horde
  */
@@ -32,17 +40,26 @@ class Menu {
      */
     function createItem($url, $text, $icon = '', $icon_path = null, $target = '', $onclick = null, $cell_class = null, $link_class = 'menuitem')
     {
-        global $conf;
+        global $conf, $prefs;
 
-        $html = '<td align="center" valign="bottom" nowrap="nowrap"';
+        $html = '<td align="center" nowrap="nowrap" valign="';
+        $html .= ($prefs->getValue('menu_view') == 'icon') ? 'middle' : 'bottom';
+        $html .= '"';
         $html .= (!empty($cell_class)) ? " class=\"$cell_class\">" : '>';
         $html .= Horde::link($url, $text, $link_class, $target, $onclick);
 
-        if (!empty($icon) && $conf['menu']['images']) {
-            $html .= Horde::img($icon, "alt=\"$text\"", $icon_path) . '<br />';
+        if (!empty($icon) && ($prefs->getValue('menu_view') == 'icon' || $prefs->getValue('menu_view') == 'both')) {
+            $html .= Horde::img($icon, "alt=\"$text\"" . ($prefs->getValue('menu_view') == 'icon' ? 'hspace="5" vspace="5"' : ''), $icon_path);
+            if ($prefs->getValue('menu_view') == 'both') {
+                $html .= '<br />';
+            }
         }
 
-        $html .= $text . "</a>&nbsp;</td>\n";
+        if ($prefs->getValue('menu_view') != 'icon') {
+            $html .= $text;
+        }
+
+        $html .= "</a>&nbsp;</td>\n";
 
         return $html;
     }
@@ -64,7 +81,7 @@ class Menu {
      */
     function printItem($url, $text, $icon = '', $icon_path = null, $target = '', $onclick = null, $cell_class = null, $link_class = 'menuitem')
     {
-        echo Menu::createItem($url, $text, $icon, $icon_path, $target, $onclick);
+        echo Menu::createItem($url, $text, $icon, $icon_path, $target, $onclick, $cell_class, $link_class);
     }
 
     /**
