@@ -1,5 +1,12 @@
 <?php
-// $Horde: horde/lib/base.php,v 1.3.2.3 2002/04/17 22:58:27 jan Exp $
+/*
+ * $Horde: horde/lib/base.php,v 1.3.2.6 2003/01/03 12:48:38 jan Exp $
+ *
+ * Copyright 1999-2003 Chuck Hagenbuch <chuck@horde.org>
+ *
+ * See the enclosed file COPYING for license information (LGPL). If you
+ * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
+ */
 
 /*
  * Horde base inclusion file.
@@ -22,12 +29,6 @@ $registry->pushApp('horde');
 $conf = &$GLOBALS['conf'];
 @define('HORDE_TEMPLATES', $registry->getParam('templates'));
 
-// set error reporting according to config settings
-error_reporting($conf['debug_level']);
-
-// set max execution time according to config settings
-set_time_limit($conf['max_exec_time']);
-
 // Horde base libraries
 require_once HORDE_BASE . '/lib/Horde.php';
 require_once HORDE_BASE . '/lib/Auth.php';
