@@ -1,10 +1,10 @@
-# $Horde: horde/scripts/db/mysql_drop.sql,v 1.1.2.1 2001/11/27 04:27:32 chuck Exp $
+# $Horde: horde/scripts/db/mysql_drop.sql,v 1.1.2.2 2002/09/25 22:58:25 jan Exp $
 #
 # You can simply direct this file to mysql as STDIN:
 #
 # $ mysql --user=root --password=<MySQL-root-password> < mysql_drop.sql
 
-CONNECT mysql;
+USE mysql;
 
 DELETE FROM user WHERE user LIKE 'horde%';
 
