@@ -1,13 +1,13 @@
 <form method="post">
-<textarea name="css" rows="8" cols="80"><?php if (!empty($HTTP_POST_VARS['css'])) echo $HTTP_POST_VARS['css'] ?></textarea>
+<textarea name="css" rows="8" cols="80"><?php if (!empty($_POST['css'])) echo $_POST['css'] ?></textarea>
 <br />
 <input type="submit" />
 </form>
 
 <?php
 
-if (isset($HTTP_POST_VARS['css'])) {
-    $css = get_magic_quotes_gpc() ? stripslashes($HTTP_POST_VARS['css']) : $HTTP_POST_VARS['css'];
+if (isset($_POST['css'])) {
+    $css = get_magic_quotes_gpc() ? stripslashes($_POST['css']) : $_POST['css'];
     $items = explode('}', $css);
     $styles = array();
     foreach ($items as $item) {
